@@ -16,6 +16,7 @@ basic_wsgi_req = {
     "QUERY_STRING": "user=JohnDoe&age=30&age=35",
     "CONTENT_TYPE": "application/json",
     "REMOTE_ADDR": "198.51.100.23",
+    "HTTP_USER_AGENT": "Mozilla/5.0",
 }
 
 
@@ -71,6 +72,7 @@ def test_wsgi_context_1():
         "executed_middleware": False,
         "route_params": [],
     }
+    assert context.get_user_agent() is None
 
 
 def test_wsgi_context_2():
@@ -84,6 +86,7 @@ def test_wsgi_context_2():
             "COOKIE": "sessionId=abc123xyz456;",
             "HOST": "localhost:8080",
             "CONTENT_TYPE": "application/json",
+            "USER_AGENT": "Mozilla/5.0",
         },
         "cookies": {"sessionId": "abc123xyz456"},
         "url": "http://localhost:8080/hello",
@@ -99,6 +102,7 @@ def test_wsgi_context_2():
         "executed_middleware": False,
         "route_params": [],
     }
+    assert context.get_user_agent() == "Mozilla/5.0"
 
 
 def test_set_as_current_context(mocker):
@@ -130,6 +134,7 @@ def test_context_is_picklable(mocker):
         "COOKIE": "sessionId=abc123xyz456;",
         "HOST": "localhost:8080",
         "CONTENT_TYPE": "application/json",
+        "USER_AGENT": "Mozilla/5.0",
     }
     assert unpickled_obj.query == {"user": ["JohnDoe"], "age": ["30", "35"]}
     assert unpickled_obj.cookies == {"sessionId": "abc123xyz456"}
@@ -159,6 +164,18 @@ def test_set_empty_byte_string():
     assert context.body is None
 
 
+def test_set_normal_byte_string():
+    body = b"Hello World!"
+    context = Context(req=basic_wsgi_req, body=body, source="flask")
+    assert context.body == "Hello World!"
+
+
+def test_set_byte_string_wrong_encoding():
+    body = "hello world! 😊".encode("utf-16")  # UTF-16 unique character
+    context = Context(req=basic_wsgi_req, body=body, source="flask")
+    assert context.body == body  # Body remains unchanged because utf-8 failed.
+
+
 def test_set_none():
     context = Context(req=basic_wsgi_req, body=None, source="flask")
     assert context.body is None
@@ -207,6 +224,15 @@ def test_set_valid_json_with_spaces_and_array():
     assert context.body == "               (1, 2, 3)         "
 
 
+def test_set_valid_json_with_spaces_and_array_bytes():
+    context = Context(req=basic_wsgi_req, body=None, source="flask")
+
+    context.set_body(b"               [1, 2, 3]         ")
+    assert context.body == [1, 2, 3]
+    context.set_body(b"               (1, 2, 3)         ")
+    assert context.body == "               (1, 2, 3)         "
+
+
 def test_set_valid_json_with_complex_array():
     context = Context(req=basic_wsgi_req, body=None, source="flask")
 
@@ -216,6 +242,15 @@ def test_set_valid_json_with_complex_array():
     assert context.body == [{"hello": "world", "one": 123}, 2, "hiya"]
 
 
+def test_set_valid_json_with_complex_array_bytes():
+    context = Context(req=basic_wsgi_req, body=None, source="flask")
+
+    context.set_body(
+        b'               [{"hello": "world", "one": 123}, 2, "hiya"]         '
+    )
+    assert context.body == [{"hello": "world", "one": 123}, 2, "hiya"]
+
+
 def test_empty_string_becomes_none():
     context = Context(req=basic_wsgi_req, body=None, source="flask")
 
@@ -227,3 +262,9 @@ def test_set_valid_json_with_special_characters():
     context = Context(req=basic_wsgi_req, body=None, source="flask")
     context.set_body('{"key": "value with special characters !@#$%^&*()"}')
     assert context.body == {"key": "value with special characters !@#$%^&*()"}
+
+
+def test_set_valid_json_with_special_characters_bytes():
+    context = Context(req=basic_wsgi_req, body=None, source="flask")
+    context.set_body(b'{"key": "value with special characters !@#$%^&*()"}')
+    assert context.body == {"key": "value with special characters !@#$%^&*()"}
